@@ -1,10 +1,9 @@
 use axum::{
-    body::{Bytes, Full},
+    body::BoxBody,
     http::Response,
     response::IntoResponse,
 };
 use axum_debug::debug_handler;
-use std::convert::Infallible;
 
 struct A;
 
@@ -16,10 +15,7 @@ impl A {
 }
 
 impl IntoResponse for A {
-    type Body = Full<Bytes>;
-    type BodyError = Infallible;
-
-    fn into_response(self) -> Response<Self::Body> {
+    fn into_response(self) -> Response<BoxBody> {
         todo!()
     }
 }
